@@ -6,7 +6,7 @@ import aioredis
 from asgi_tools._compat import json_dumps, json_loads
 
 from muffin import Application
-from muffin.plugin import BasePlugin
+from muffin.plugins import BasePlugin
 
 try:
     import fakeredis
@@ -15,7 +15,7 @@ except ImportError:
     fakeredis = None
     fake_aioredis = None
 
-__version__ = "2.0.0"
+__version__ = "2.0.4"
 
 
 class Plugin(BasePlugin):
